@@ -108,6 +108,13 @@
 	    :selected (eq browse-url-browser-function 'browse-url-mozilla)
 	    :active (and (fboundp 'browse-url-mozilla)
 			 (executable-find browse-url-mozilla-program))]
+	   ["%_Firefox"
+	    (customize-set-variable 'browse-url-browser-function
+				    'browse-url-firefox)
+	    :style radio
+	    :selected (eq browse-url-browser-function 'browse-url-firefox)
+	    :active (and (fboundp 'browse-url-firefox)
+			 (executable-find browse-url-firefox-program))]
 	   ["G%_aleon"
 	    (customize-set-variable 'browse-url-browser-function
 				    'browse-url-galeon)
